@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Authors:
  *  Manjeet Dahiya
@@ -28,7 +28,7 @@
 
 #include "QXmppBindIq.h"
 #include "QXmppUtils.h"
-#include "QXmppConstants.h"
+#include "QXmppConstants_p.h"
 
 /// Returns the bound JID.
 ///
