@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -34,7 +34,7 @@ public:
     enum Mode {
         None = 0,
         Tcp,
-        Udp,
+        Udp
     };
 
     class QXMPP_EXPORT StreamHost
