@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -22,7 +22,7 @@
  */
 
 
-#include "QXmppConstants.h"
+#include "QXmppConstants_p.h"
 
 const char* ns_stream = "http://etherx.jabber.org/streams";
 const char* ns_client = "jabber:client";
@@ -57,6 +57,8 @@ const char* ns_vcard = "vcard-temp";
 const char* ns_rsm = "http://jabber.org/protocol/rsm";
 // XEP-0065: SOCKS5 Bytestreams
 const char* ns_bytestreams = "http://jabber.org/protocol/bytestreams";
+// XEP-0066: Out of Band Data
+const char* ns_oob = "jabber:x:oob";
 // XEP-0071: XHTML-IM
 const char *ns_xhtml_im = "http://jabber.org/protocol/xhtml-im";
 // XEP-0077: In-Band Registration
@@ -98,6 +100,8 @@ const char* ns_jingle_rtp_audio = "urn:xmpp:jingle:apps:rtp:audio";
 const char* ns_jingle_rtp_video = "urn:xmpp:jingle:apps:rtp:video";
 // XEP-0184: Message Receipts
 const char* ns_message_receipts = "urn:xmpp:receipts";
+// XEP-0198: Stream Management
+const char* ns_stream_management = "urn:xmpp:sm:3";
 // XEP-0199: XMPP Ping
 const char* ns_ping = "urn:xmpp:ping";
 // XEP-0202: Entity Time
@@ -114,5 +118,17 @@ const char* ns_attention = "urn:xmpp:attention:0";
 const char* ns_bob = "urn:xmpp:bob";
 // XEP-0249: Direct MUC Invitations
 const char* ns_conference = "jabber:x:conference";
+// XEP-0280: Message Carbons
+const char* ns_carbons = "urn:xmpp:carbons:2";
+// XEP-0297: Stanza Forwarding
+const char* ns_forwarding = "urn:xmpp:forward:0";
+// XEP-0308: Last Message Correction
+const char* ns_message_correct = "urn:xmpp:message-correct:0";
+// XEP-0313: Message Archive Management
+const char* ns_mam = "urn:xmpp:mam:1";
+// XEP-0319: Last User Interaction in Presence
+const char* ns_idle = "urn:xmpp:idle:1";
 // XEP-0333: Chat Markers
 const char* ns_chat_markers = "urn:xmpp:chat-markers:0";
+// XEP-0352: Client State Indication
+const char* ns_csi = "urn:xmpp:csi:0";
