@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -26,7 +26,7 @@
 #include <QDomElement>
 #include <QRegExp>
 
-#include "QXmppConstants.h"
+#include "QXmppConstants_p.h"
 #include "QXmppJingleIq.h"
 #include "QXmppUtils.h"
 
@@ -710,7 +710,8 @@ public:
 };
 
 QXmppJingleIqPrivate::QXmppJingleIqPrivate()
-    : ringing(false)
+    : action(QXmppJingleIq::ContentAccept)
+    , ringing(false)
 {
 }
 
