@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Authors:
  *  Manjeet Dahiya
@@ -27,7 +27,7 @@
 #include <QXmlStreamWriter>
 #include <QPair>
 
-#include "QXmppConstants.h"
+#include "QXmppConstants_p.h"
 #include "QXmppMessage.h"
 #include "QXmppUtils.h"
 
@@ -93,6 +93,15 @@ public:
     QXmppMessage::Marker marker;
     QString markedId;
     QString markedThread;
+
+    // XEP-0280: Message Carbons
+    bool privatemsg;
+
+    // XEP-0066: Out of Band Data
+    QString outOfBandUrl;
+
+    // XEP-0308: Last Message Correction
+    QString replaceId;
 };
 
 /// Constructs a QXmppMessage.
@@ -117,6 +126,8 @@ QXmppMessage::QXmppMessage(const QString& from, const QString& to, const
 
     d->markable = false;
     d->marker = NoMarker;
+
+    d->privatemsg = false;
 }
 
 /// Constructs a copy of \a other.
@@ -369,10 +380,12 @@ namespace
                << qMakePair(QString("thread"), QString())
                << qMakePair(QString("html"), QString())
                << qMakePair(QString("received"), QString(ns_message_receipts))
+               << qMakePair(QString("replace"), QString(ns_message_correct))
                << qMakePair(QString("request"), QString())
                << qMakePair(QString("delay"), QString())
                << qMakePair(QString("attention"), QString())
-               << qMakePair(QString("addresses"), QString());
+               << qMakePair(QString("addresses"), QString())
+               << qMakePair(QString("private"), QString(ns_carbons));
         for (int i = QXmppMessage::Active; i <= QXmppMessage::Paused; i++)
             result << qMakePair(QString(chat_states[i]), QString());
         return result;
@@ -443,6 +456,63 @@ void QXmppMessage::setMarker(const Marker marker)
     d->marker = marker;
 }
 
+/// Returns if the message is marked with a <private> tag,
+/// in which case it will not be forwarded to other resources
+/// according to XEP-0280: Message Carbons.
+
+bool QXmppMessage::isPrivate() const
+{
+    return d->privatemsg;
+}
+
+/// If true is passed, the message is marked with a <private> tag,
+/// in which case it will not be forwarded to other resources
+/// according to XEP-0280: Message Carbons.
+
+void QXmppMessage::setPrivate(const bool priv)
+{
+    d->privatemsg = priv;
+}
+
+/// Indicates if the QXmppStanza is a stanza in the XMPP sense (i. e. a message,
+/// iq or presence)
+
+bool QXmppMessage::isXmppStanza() const
+{
+    return true;
+}
+
+/// Returns a possibly attached URL from XEP-0066: Out of Band Data
+
+QString QXmppMessage::outOfBandUrl() const
+{
+    return d->outOfBandUrl;
+}
+
+/// Sets the attached URL for XEP-0066: Out of Band Data
+
+void QXmppMessage::setOutOfBandUrl(const QString &url)
+{
+    d->outOfBandUrl = url;
+}
+
+/// Returns the message id to replace with this message as used in XEP-0308:
+/// Last Message Correction. If the returned string is empty, this message is
+/// not replacing another.
+
+QString QXmppMessage::replaceId() const
+{
+    return d->replaceId;
+}
+
+/// Sets the message id to replace with this message as in XEP-0308: Last
+/// Message Correction.
+
+void QXmppMessage::setReplaceId(const QString &replaceId)
+{
+    d->replaceId = replaceId;
+}
+
 /// \cond
 void QXmppMessage::parse(const QDomElement &element)
 {
@@ -543,6 +613,16 @@ void QXmppMessage::parse(const QDomElement &element)
         }
     }
 
+    // XEP-0280: Message Carbons
+    QDomElement privateElement = element.firstChildElement("private");
+    if (!privateElement.isNull())
+        d->privatemsg = true;
+
+    // XEP-0308: Last Message Correction
+    QDomElement replaceElement = element.firstChildElement("replace");
+    if (!replaceElement.isNull() && replaceElement.namespaceURI() == ns_message_correct)
+        d->replaceId = replaceElement.attribute("id");
+
     const QList<QPair<QString, QString> > &knownElems = knownMessageSubelems();
 
     QXmppElementList extensions;
@@ -567,6 +647,9 @@ void QXmppMessage::parse(const QDomElement &element)
                 d->mucInvitationJid = xElement.attribute("jid");
                 d->mucInvitationPassword = xElement.attribute("password");
                 d->mucInvitationReason = xElement.attribute("reason");
+            } else if (xElement.namespaceURI() == ns_oob) {
+                // XEP-0066: Out of Band Data
+                d->outOfBandUrl = xElement.firstChildElement("url").text();
             }
             else {
                 extensions << QXmppElement(xElement);
@@ -685,6 +768,29 @@ void QXmppMessage::toXml(QXmlStreamWriter *xmlWriter) const
         xmlWriter->writeEndElement();
     }
 
+    // XEP-0280: Message Carbons
+    if (d->privatemsg) {
+        xmlWriter->writeStartElement("private");
+        xmlWriter->writeAttribute("xmlns", ns_carbons);
+        xmlWriter->writeEndElement();
+    }
+
+    // XEP-0066: Out of Band Data
+    if (!d->outOfBandUrl.isEmpty()) {
+        xmlWriter->writeStartElement("x");
+        xmlWriter->writeAttribute("xmlns", ns_oob);
+        xmlWriter->writeTextElement("url", d->outOfBandUrl);
+        xmlWriter->writeEndElement();
+    }
+
+    // XEP-0308: Last Message Correction
+    if (!d->replaceId.isEmpty()) {
+        xmlWriter->writeStartElement("replace");
+        xmlWriter->writeAttribute("xmlns", ns_message_correct);
+        xmlWriter->writeAttribute("id", d->replaceId);
+        xmlWriter->writeEndElement();
+    }
+
     // other extensions
     QXmppStanza::extensionsToXml(xmlWriter);
 
