@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -57,7 +57,7 @@ public:
         Inactive,   ///< User has not been actively participating in the chat session.
         Gone,       ///< User has effectively ended their participation in the chat session.
         Composing,  ///< User is composing a message.
-        Paused,     ///< User had been composing but now has stopped.
+        Paused      ///< User had been composing but now has stopped.
     };
 
     /// This enum describes a chat marker as defined by
@@ -129,6 +129,20 @@ public:
     Marker marker() const;
     void setMarker(const Marker);
 
+    // XEP-0280: Message Carbons
+    bool isPrivate() const;
+    void setPrivate(const bool);
+
+    bool isXmppStanza() const;
+
+    // XEP-0066: Out of Band Data
+    QString outOfBandUrl() const;
+    void setOutOfBandUrl(const QString&);
+
+    // XEP-0308: Last Message Correction
+    QString replaceId() const;
+    void setReplaceId(const QString&);
+
     /// \cond
     void parse(const QDomElement &element);
     void toXml(QXmlStreamWriter *writer) const;
