@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -25,7 +25,7 @@
 #include <QDomElement>
 #include <QXmlStreamWriter>
 
-#include "QXmppConstants.h"
+#include "QXmppConstants_p.h"
 #include "QXmppNonSASLAuth.h"
 #include "QXmppUtils.h"
 
