@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -21,7 +21,7 @@
  *
  */
 
-#include "QXmppConstants.h"
+#include "QXmppConstants_p.h"
 #include "QXmppPingIq.h"
 #include "QXmppUtils.h"
 
