@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -128,6 +128,12 @@ public:
 
     QStringList capabilityExt() const;
 
+    // XEP-0319: Last User Interaction in Presence
+    QDateTime lastUserInteraction() const;
+    void setLastUserInteraction(const QDateTime&);
+
+    bool isXmppStanza() const;
+
 private:
     QSharedDataPointer<QXmppPresencePrivate> d;
 };
