@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -68,7 +68,7 @@ public:
         SubscribeQuery,
         SubscriptionQuery,
         SubscriptionsQuery,
-        UnsubscribeQuery,
+        UnsubscribeQuery
     };
 
     QXmppPubSubIq::QueryType queryType() const;
