@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Authors:
  *  Ian Reinhart Geiser
@@ -28,7 +28,7 @@
 #include <QDateTime>
 #include <QStringList>
 
-#include "QXmppConstants.h"
+#include "QXmppConstants_p.h"
 #include "QXmppRpcIq.h"
 #include "QXmppUtils.h"
 
