@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Authors:
  *  Manjeet Dahiya
@@ -26,7 +26,7 @@
 #include <QXmlStreamWriter>
 
 #include "QXmppSessionIq.h"
-#include "QXmppConstants.h"
+#include "QXmppConstants_p.h"
 #include "QXmppUtils.h"
 
 /// \cond
