@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -23,14 +23,16 @@
 
 #include <QDomElement>
 
-#include "QXmppConstants.h"
+#include "QXmppConstants_p.h"
 #include "QXmppStreamFeatures.h"
 
 QXmppStreamFeatures::QXmppStreamFeatures()
     : m_bindMode(Disabled),
     m_sessionMode(Disabled),
     m_nonSaslAuthMode(Disabled),
-    m_tlsMode(Disabled)
+    m_tlsMode(Disabled),
+    m_streamManagementMode(Disabled),
+    m_csiMode(Disabled)
 {
 }
 
@@ -94,6 +96,26 @@ void QXmppStreamFeatures::setTlsMode(QXmppStreamFeatures::Mode mode)
     m_tlsMode = mode;
 }
 
+QXmppStreamFeatures::Mode QXmppStreamFeatures::streamManagementMode() const
+{
+    return m_streamManagementMode;
+}
+
+void QXmppStreamFeatures::setStreamManagementMode(QXmppStreamFeatures::Mode mode)
+{
+    m_streamManagementMode = mode;
+}
+
+QXmppStreamFeatures::Mode QXmppStreamFeatures::clientStateIndicationMode() const
+{
+    return m_csiMode;
+}
+
+void QXmppStreamFeatures::setClientStateIndicationMode(QXmppStreamFeatures::Mode mode)
+{
+    m_csiMode = mode;
+}
+
 /// \cond
 bool QXmppStreamFeatures::isStreamFeatures(const QDomElement &element)
 {
@@ -104,15 +126,18 @@ bool QXmppStreamFeatures::isStreamFeatures(const QDomElement &element)
 static QXmppStreamFeatures::Mode readFeature(const QDomElement &element, const char *tagName, const char *tagNs)
 {
     QDomElement subElement = element.firstChildElement(tagName);
-    if (subElement.namespaceURI() == tagNs)
-    {
-        if (!subElement.firstChildElement("required").isNull())
-            return QXmppStreamFeatures::Required;
-        else
-            return QXmppStreamFeatures::Enabled;
-    } else {
-        return QXmppStreamFeatures::Disabled;
+    QXmppStreamFeatures::Mode mode = QXmppStreamFeatures::Disabled;
+    while (!subElement.isNull()) {
+        if (subElement.namespaceURI() == tagNs)
+        {
+            if (!subElement.firstChildElement("required").isNull())
+                mode = QXmppStreamFeatures::Required;
+            else if (mode != QXmppStreamFeatures::Required)
+                mode = QXmppStreamFeatures::Enabled;
+        }
+        subElement = subElement.nextSiblingElement(tagName);
     }
+    return mode;
 }
 
 void QXmppStreamFeatures::parse(const QDomElement &element)
@@ -121,6 +146,8 @@ void QXmppStreamFeatures::parse(const QDomElement &element)
     m_sessionMode = readFeature(element, "session", ns_session);
     m_nonSaslAuthMode = readFeature(element, "auth", ns_authFeature);
     m_tlsMode = readFeature(element, "starttls", ns_tls);
+    m_streamManagementMode = readFeature(element, "sm", ns_stream_management);
+    m_csiMode = readFeature(element, "csi", ns_csi);
 
     // parse advertised compression methods
     QDomElement compression = element.firstChildElement("compression");
@@ -165,6 +192,8 @@ void QXmppStreamFeatures::toXml(QXmlStreamWriter *writer) const
     writeFeature(writer, "session", ns_session, m_sessionMode);
     writeFeature(writer, "auth", ns_authFeature, m_nonSaslAuthMode);
     writeFeature(writer, "starttls", ns_tls, m_tlsMode);
+    writeFeature(writer, "sm", ns_stream_management, m_streamManagementMode);
+    writeFeature(writer, "csi", ns_csi, m_csiMode);
 
     if (!m_compressionMethods.isEmpty())
     {
