@@ -1,11 +1,11 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
  *
  * Source:
- *  http://code.google.com/p/qxmpp
+ *  https://github.com/qxmpp-project/qxmpp
  *
  * This file is a part of QXmpp library.
  *
@@ -56,6 +56,23 @@ public:
     Mode tlsMode() const;
     void setTlsMode(Mode mode);
 
+    /// Returns the mode (disabled, enabled or required) for XEP-0198: Stream
+    /// Management
+    Mode streamManagementMode() const;
+
+    /// Sets the mode for XEP-0198: Stream Management
+    ///
+    /// \pa mode The mode to set.
+    void setStreamManagementMode(Mode mode);
+
+    /// Returns the mode for XEP-0352: Client State Indication
+    Mode clientStateIndicationMode() const;
+
+    /// Sets the mode for XEP-0352: Client State Indication
+    ///
+    /// \pa mode The mode to set.
+    void setClientStateIndicationMode(Mode mode);
+
     /// \cond
     void parse(const QDomElement &element);
     void toXml(QXmlStreamWriter *writer) const;
@@ -68,6 +85,8 @@ private:
     Mode m_sessionMode;
     Mode m_nonSaslAuthMode;
     Mode m_tlsMode;
+    Mode m_streamManagementMode;
+    Mode m_csiMode;
     QStringList m_authMechanisms;
     QStringList m_compressionMethods;
 };
