@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -26,7 +26,7 @@
 
 #include "QXmppClient.h"
 #include "QXmppClientExtension.h"
-#include "QXmppConstants.h"
+#include "QXmppConstants_p.h"
 #include "QXmppLogger.h"
 #include "QXmppOutgoingClient.h"
 #include "QXmppMessage.h"
@@ -54,6 +54,9 @@ public:
     int reconnectionTries;
     QTimer *reconnectionTimer;
 
+    // Client state indication
+    bool isActive;
+
     void addProperCapability(QXmppPresence& presence);
     int getNextReconnectTime() const;
 
@@ -68,6 +71,7 @@ QXmppClientPrivate::QXmppClientPrivate(QXmppClient *qq)
     , receivedConflict(false)
     , reconnectionTries(0)
     , reconnectionTimer(0)
+    , isActive(true)
     , q(qq)
 {
 }
@@ -320,6 +324,25 @@ bool QXmppClient::isConnected() const
     return d->stream->isConnected();
 }
 
+/// Returns true if the current client state is "active", false if it is
+/// "inactive". See XEP-0352 for details.
+
+bool QXmppClient::isActive() const
+{
+    return d->isActive;
+}
+
+/// Sets the client state as described in XEP-0352
+
+void QXmppClient::setActive(bool active)
+{
+    if (active != d->isActive && d->stream->isClientStateIndicationEnabled()) {
+        d->isActive = active;
+        QString packet = "<%1 xmlns='%2'/>";
+        d->stream->sendData(packet.arg(active ? "active" : "inactive", ns_csi).toUtf8());
+    }
+}
+
 /// Returns the reference to QXmppRosterManager object of the client.
 /// \return Reference to the roster object of the connected client. Use this to
 /// get the list of friends in the roster and their presence information.
