@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Manjeet Dahiya
@@ -31,6 +31,8 @@
 #include "QXmppLogger.h"
 #include "QXmppPresence.h"
 
+class QSslError;
+
 class QXmppClientExtension;
 class QXmppClientPrivate;
 class QXmppPresence;
@@ -62,7 +64,7 @@ class QXmppVersionManager;
 /// QXmppConfiguration::setAutoReconnectionEnabled().
 ///
 /// Not all the managers or extensions have been enabled by default. One can
-/// enable/disable the managers using the funtions addExtension() and
+/// enable/disable the managers using the functions addExtension() and
 /// removeExtension(). findExtension() can be used to find reference/pointer to
 /// particular instansiated and enabled manager.
 ///
@@ -90,7 +92,7 @@ public:
         NoError,            ///< No error.
         SocketError,        ///< Error due to TCP socket.
         KeepAliveError,     ///< Error due to no response to a keep alive.
-        XmppStreamError,    ///< Error due to XML stream.
+        XmppStreamError     ///< Error due to XML stream.
     };
 
     /// This enumeration describes a client state.
@@ -98,7 +100,7 @@ public:
     {
         DisconnectedState,  ///< Disconnected from the server.
         ConnectingState,    ///< Trying to connect to the server.
-        ConnectedState,     ///< Connected to the server.
+        ConnectedState      ///< Connected to the server.
     };
 
     QXmppClient(QObject *parent = 0);
@@ -135,12 +137,12 @@ public:
         return 0;
     }
 
-    void connectToServer(const QXmppConfiguration&,
-                         const QXmppPresence& initialPresence =
-                         QXmppPresence());
     bool isAuthenticated() const;
     bool isConnected() const;
 
+    bool isActive() const;
+    void setActive(bool active);
+
     QXmppPresence clientPresence() const;
     void setClientPresence(const QXmppPresence &presence);
 
@@ -212,10 +214,17 @@ signals:
     /// management, setting-getting vCards etc is done using iq stanzas.
     void iqReceived(const QXmppIq &iq);
 
+    /// This signal is emitted to indicate that one or more SSL errors were
+    /// encountered while establishing the identity of the server.
+    void sslErrors(const QList<QSslError> &errors);
+
     /// This signal is emitted when the client state changes.
     void stateChanged(QXmppClient::State state);
 
 public slots:
+    void connectToServer(const QXmppConfiguration&,
+                         const QXmppPresence& initialPresence =
+                         QXmppPresence());
     void connectToServer(const QString &jid,
                          const QString &password);
     void disconnectFromServer();
