@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Authors:
  *  Manjeet Dahiya
@@ -26,20 +26,17 @@
 #include <QNetworkProxy>
 #include <QSslSocket>
 #include <QUrl>
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
 #include <QDnsLookup>
-#else
-#include "qdnslookup.h"
-#endif
 
 #include "QXmppConfiguration.h"
-#include "QXmppConstants.h"
+#include "QXmppConstants_p.h"
 #include "QXmppIq.h"
 #include "QXmppLogger.h"
 #include "QXmppMessage.h"
 #include "QXmppPresence.h"
 #include "QXmppOutgoingClient.h"
 #include "QXmppStreamFeatures.h"
+#include "QXmppStreamManagement_p.h"
 #include "QXmppNonSASLAuth.h"
 #include "QXmppSasl_p.h"
 #include "QXmppUtils.h"
@@ -63,6 +60,13 @@ class QXmppOutgoingClientPrivate
 public:
     QXmppOutgoingClientPrivate(QXmppOutgoingClient *q);
     void connectToHost(const QString &host, quint16 port);
+    void connectToNextDNSHost();
+
+    void sendNonSASLAuth(bool plaintext);
+    void sendNonSASLAuthQuery();
+    void sendBind();
+    void sendSessionStart();
+    void sendStreamManagementEnable();
 
     // This object provides the configuration
     // required for connecting to the XMPP server.
@@ -71,6 +75,7 @@ public:
 
     // DNS
     QDnsLookup dns;
+    int nextSrvRecordIdx;
 
     // Stream
     QString streamId;
@@ -84,6 +89,7 @@ public:
     // Session
     QString bindId;
     QString sessionId;
+    bool bindModeAvailable;
     bool sessionAvailable;
     bool sessionStarted;
 
@@ -92,6 +98,17 @@ public:
     QString nonSASLAuthId;
     QXmppSaslClient *saslClient;
 
+    // Stream Management
+    bool streamManagementAvailable;
+    QString smId;
+    bool canResume;
+    bool isResuming;
+    QString resumeHost;
+    quint16 resumePort;
+
+    // Client State Indication
+    bool clientStateIndicationEnabled;
+
     // Timers
     QTimer *pingTimer;
     QTimer *timeoutTimer;
@@ -101,11 +118,18 @@ private:
 };
 
 QXmppOutgoingClientPrivate::QXmppOutgoingClientPrivate(QXmppOutgoingClient *qq)
-    : redirectPort(0)
+    : nextSrvRecordIdx(0)
+    , redirectPort(0)
+    , bindModeAvailable(false)
     , sessionAvailable(false)
     , sessionStarted(false)
     , isAuthenticated(false)
     , saslClient(0)
+    , streamManagementAvailable(false)
+    , canResume(false)
+    , isResuming(false)
+    , resumePort(0)
+    , clientStateIndicationEnabled(false)
     , pingTimer(0)
     , timeoutTimer(0)
     , q(qq)
@@ -123,10 +147,8 @@ void QXmppOutgoingClientPrivate::connectToHost(const QString &host, quint16 port
     // respect proxy
     q->socket()->setProxy(config.networkProxy());
 
-#if (QT_VERSION >= QT_VERSION_CHECK(4, 8, 0))
     // set the name the SSL certificate should match
     q->socket()->setPeerVerifyName(config.domain());
-#endif
 
     // connect to host
     const QXmppConfiguration::StreamSecurityMode localSecurity = q->configuration().streamSecurityMode();
@@ -141,6 +163,15 @@ void QXmppOutgoingClientPrivate::connectToHost(const QString &host, quint16 port
     }
 }
 
+void QXmppOutgoingClientPrivate::connectToNextDNSHost()
+{
+    connectToHost(
+        dns.serviceRecords().at(nextSrvRecordIdx).target(),
+        dns.serviceRecords().at(nextSrvRecordIdx).port());
+
+    nextSrvRecordIdx++;
+}
+
 /// Constructs an outgoing client stream.
 ///
 /// \param parent
@@ -212,6 +243,12 @@ QXmppConfiguration& QXmppOutgoingClient::configuration()
 
 void QXmppOutgoingClient::connectToHost()
 {
+    // if a host for resumption is available, connect to it
+    if (d->canResume && !d->resumeHost.isEmpty() && d->resumePort) {
+        d->connectToHost(d->resumeHost, d->resumePort);
+        return;
+    }
+
     // if an explicit host was provided, connect to it
     if (!d->config.host().isEmpty() && d->config.port()) {
         d->connectToHost(d->config.host(), d->config.port());
@@ -224,6 +261,13 @@ void QXmppOutgoingClient::connectToHost()
     d->dns.setName("_xmpp-client._tcp." + domain);
     d->dns.setType(QDnsLookup::SRV);
     d->dns.lookup();
+    d->nextSrvRecordIdx = 0;
+}
+
+void QXmppOutgoingClient::disconnectFromHost()
+{
+    d->canResume = false;
+    QXmppStream::disconnectFromHost();
 }
 
 void QXmppOutgoingClient::_q_dnsLookupFinished()
@@ -231,9 +275,7 @@ void QXmppOutgoingClient::_q_dnsLookupFinished()
     if (d->dns.error() == QDnsLookup::NoError &&
         !d->dns.serviceRecords().isEmpty()) {
         // take the first returned record
-        d->connectToHost(
-            d->dns.serviceRecords().first().target(),
-            d->dns.serviceRecords().first().port());
+        d->connectToNextDNSHost();
     } else {
         // as a fallback, use domain as the host name
         warning(QString("Lookup for domain %1 failed: %2")
@@ -256,6 +298,13 @@ bool QXmppOutgoingClient::isConnected() const
     return QXmppStream::isConnected() && d->sessionStarted;
 }
 
+/// Returns true if client state indication (xep-0352) is supported by the server
+
+bool QXmppOutgoingClient::isClientStateIndicationEnabled() const
+{
+    return d->clientStateIndicationEnabled;
+}
+
 void QXmppOutgoingClient::_q_socketDisconnected()
 {
     debug("Socket disconnected");
@@ -287,7 +336,14 @@ void QXmppOutgoingClient::socketSslErrors(const QList<QSslError> &errors)
 void QXmppOutgoingClient::socketError(QAbstractSocket::SocketError socketError)
 {
     Q_UNUSED(socketError);
-    emit error(QXmppClient::SocketError);
+    if ( !d->sessionStarted &&
+         (d->dns.serviceRecords().count() > d->nextSrvRecordIdx) )
+    {
+        // some network error occurred during startup -> try next available SRV record server
+        d->connectToNextDNSHost();
+    }
+    else
+        emit error(QXmppClient::SocketError);
 }
 
 /// \cond
@@ -332,7 +388,7 @@ void QXmppOutgoingClient::handleStream(const QDomElement &streamElement)
         // no version specified, signals XMPP Version < 1.0.
         // switch to old auth mechanism if enabled
         if(d->streamVersion.isEmpty() && configuration().useNonSASLAuthentication()) {
-            sendNonSASLAuthQuery();
+            d->sendNonSASLAuthQuery();
         }
     }
 }
@@ -355,6 +411,9 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
         QXmppStreamFeatures features;
         features.parse(nodeRecv);
 
+        if(features.clientStateIndicationMode() == QXmppStreamFeatures::Enabled)
+            d->clientStateIndicationEnabled = true;
+
         if (!socket()->isEncrypted())
         {
             // determine TLS mode to use
@@ -451,38 +510,41 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
             sendPacket(QXmppSaslAuth(d->saslClient->mechanism(), response));
             return;
         } else if(nonSaslAvailable && configuration().useNonSASLAuthentication()) {
-            sendNonSASLAuthQuery();
+            d->sendNonSASLAuthQuery();
             return;
         }
 
-        // store whether session is available
+        // store which features are available
         d->sessionAvailable = (features.sessionMode() != QXmppStreamFeatures::Disabled);
+        d->bindModeAvailable = (features.bindMode() != QXmppStreamFeatures::Disabled);
+        d->streamManagementAvailable = (features.streamManagementMode() != QXmppStreamFeatures::Disabled);
+
+        // chech whether the stream can be resumed
+        if (d->streamManagementAvailable && d->canResume) {
+            d->isResuming = true;
+            QXmppStreamManagementResume streamManagementResume(lastIncomingSequenceNumber(), d->smId);
+            QByteArray data;
+            QXmlStreamWriter xmlStream(&data);
+            streamManagementResume.toXml(&xmlStream);
+            sendData(data);
+            return;
+        }
 
         // check whether bind is available
-        if (features.bindMode() != QXmppStreamFeatures::Disabled)
-        {
-            QXmppBindIq bind;
-            bind.setType(QXmppIq::Set);
-            bind.setResource(configuration().resource());
-            d->bindId = bind.id();
-            sendPacket(bind);
+        if (d->bindModeAvailable) {
+            d->sendBind();
             return;
         }
 
         // check whether session is available
-        if (d->sessionAvailable)
-        {
-            // start session if it is available
-            QXmppSessionIq session;
-            session.setType(QXmppIq::Set);
-            session.setTo(configuration().domain());
-            d->sessionId = session.id();
-            sendPacket(session);
-        } else {
-            // otherwise we are done
-            d->sessionStarted = true;
-            emit connected();
+        if (d->sessionAvailable) {
+            d->sendSessionStart();
+            return;
         }
+
+        // otherwise we are done
+        d->sessionStarted = true;
+        emit connected();
     }
     else if(ns == ns_stream && nodeRecv.tagName() == "error")
     {
@@ -494,7 +556,7 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
                 d->redirectPort = redirectRegex.cap(2).mid(1).toUShort();
             else
                 d->redirectPort = 5222;
-            disconnectFromHost();
+            QXmppStream::disconnectFromHost();
             return;
         }
 
@@ -571,10 +633,17 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
             {
                 QXmppSessionIq session;
                 session.parse(nodeRecv);
-
-                // xmpp connection made
                 d->sessionStarted = true;
-                emit connected();
+
+                if(d->streamManagementAvailable)
+                {
+                    d->sendStreamManagementEnable();
+                }
+                else
+                {
+                    // we are connected now
+                    emit connected();
+                }
             }
             else if(QXmppBindIq::isBindIq(nodeRecv) && id == d->bindId)
             {
@@ -597,18 +666,17 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
                         }
                     }
 
-                    if (d->sessionAvailable)
-                    {
-                        // start session if it is available
-                        QXmppSessionIq session;
-                        session.setType(QXmppIq::Set);
-                        session.setTo(configuration().domain());
-                        d->sessionId = session.id();
-                        sendPacket(session);
+                    if (d->sessionAvailable) {
+                        d->sendSessionStart();
                     } else {
-                        // otherwise we are done
                         d->sessionStarted = true;
-                        emit connected();
+
+                        if (d->streamManagementAvailable) {
+                            d->sendStreamManagementEnable();
+                        } else {
+                            // we are connected now
+                            emit connected();
+                        }
                     }
                 }
             }
@@ -653,7 +721,7 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
                         disconnectFromHost();
                         return;
                     }
-                    sendNonSASLAuth(plainText);
+                    d->sendNonSASLAuth(plainText);
                 }
             }
             // XEP-0199: XMPP Ping
@@ -705,6 +773,68 @@ void QXmppOutgoingClient::handleStanza(const QDomElement &nodeRecv)
             emit messageReceived(message);
         }
     }
+    else if(QXmppStreamManagementEnabled::isStreamManagementEnabled(nodeRecv))
+    {
+        QXmppStreamManagementEnabled streamManagementEnabled;
+        streamManagementEnabled.parse(nodeRecv);
+        d->smId = streamManagementEnabled.id();
+        d->canResume = streamManagementEnabled.resume();
+        if (streamManagementEnabled.resume() && !streamManagementEnabled.location().isEmpty()) {
+            QRegExp locationRegex("([^:]+)(:[0-9]+)?");
+            if (locationRegex.exactMatch(streamManagementEnabled.location())) {
+                d->resumeHost = locationRegex.cap(0);
+                if (!locationRegex.cap(2).isEmpty())
+                    d->resumePort = locationRegex.cap(2).mid(1).toUShort();
+                else
+                    d->resumePort = 5222;
+            } else {
+                d->resumeHost = QString();
+                d->resumePort = 0;
+            }
+        }
+
+        enableStreamManagement(true);
+        // we are connected now
+        emit connected();
+    }
+    else if(QXmppStreamManagementResumed::isStreamManagementResumed(nodeRecv))
+    {
+        QXmppStreamManagementResumed streamManagementResumed;
+        streamManagementResumed.parse(nodeRecv);
+        setAcknowledgedSequenceNumber(streamManagementResumed.h());
+        d->isResuming = false;
+
+        enableStreamManagement(false);
+        // we are connected now
+        // TODO: The stream was resumed. Therefore, we should not send presence information or request the roster.
+        emit connected();
+    }
+    else if(QXmppStreamManagementFailed::isStreamManagementFailed(nodeRecv))
+    {
+        if (d->isResuming) {
+            // resuming failed. We can try to bind a resource now.
+            d->isResuming = false;
+
+            // check whether bind is available
+            if (d->bindModeAvailable) {
+                d->sendBind();
+                return;
+            }
+
+            // check whether session is available
+            if (d->sessionAvailable) {
+                d->sendSessionStart();
+                return;
+            }
+
+            // otherwise we are done
+            d->sessionStarted = true;
+            emit connected();
+        } else {
+            // we are connected now, but stream management is disabled
+            emit connected();
+        }
+    }
 }
 /// \endcond
 
@@ -745,36 +875,63 @@ void QXmppOutgoingClient::pingSend()
 void QXmppOutgoingClient::pingTimeout()
 {
     warning("Ping timeout");
-    disconnectFromHost();
+    QXmppStream::disconnectFromHost();
     emit error(QXmppClient::KeepAliveError);
 }
 
-void QXmppOutgoingClient::sendNonSASLAuth(bool plainText)
+void QXmppOutgoingClientPrivate::sendNonSASLAuth(bool plainText)
 {
     QXmppNonSASLAuthIq authQuery;
     authQuery.setType(QXmppIq::Set);
-    authQuery.setUsername(configuration().user());
+    authQuery.setUsername(q->configuration().user());
     if (plainText)
-        authQuery.setPassword(configuration().password());
+        authQuery.setPassword(q->configuration().password());
     else
-        authQuery.setDigest(d->streamId, configuration().password());
-    authQuery.setResource(configuration().resource());
-    d->nonSASLAuthId = authQuery.id();
-    sendPacket(authQuery);
+        authQuery.setDigest(streamId, q->configuration().password());
+    authQuery.setResource(q->configuration().resource());
+    nonSASLAuthId = authQuery.id();
+    q->sendPacket(authQuery);
 }
 
-void QXmppOutgoingClient::sendNonSASLAuthQuery()
+void QXmppOutgoingClientPrivate::sendNonSASLAuthQuery()
 {
     QXmppNonSASLAuthIq authQuery;
     authQuery.setType(QXmppIq::Get);
-    authQuery.setTo(d->streamFrom);
+    authQuery.setTo(streamFrom);
     // FIXME : why are we setting the username, XEP-0078 states we should
     // not attempt to guess the required fields?
-    authQuery.setUsername(configuration().user());
-    sendPacket(authQuery);
+    authQuery.setUsername(q->configuration().user());
+    q->sendPacket(authQuery);
 }
 
-/// Returns the type of the last XMPP stream error that occured.
+void QXmppOutgoingClientPrivate::sendBind()
+{
+    QXmppBindIq bind;
+    bind.setType(QXmppIq::Set);
+    bind.setResource(q->configuration().resource());
+    bindId = bind.id();
+    q->sendPacket(bind);
+}
+
+void QXmppOutgoingClientPrivate::sendSessionStart()
+{
+    QXmppSessionIq session;
+    session.setType(QXmppIq::Set);
+    session.setTo(q->configuration().domain());
+    sessionId = session.id();
+    q->sendPacket(session);
+}
+
+void QXmppOutgoingClientPrivate::sendStreamManagementEnable()
+{
+    QXmppStreamManagementEnable streamManagementEnable(true);
+    QByteArray data;
+    QXmlStreamWriter xmlStream(&data);
+    streamManagementEnable.toXml(&xmlStream);
+    q->sendData(data);
+}
+
+/// Returns the type of the last XMPP stream error that occurred.
 
 QXmppStanza::Error::Condition QXmppOutgoingClient::xmppStreamError()
 {
