@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Authors:
  *  Manjeet Dahiya
@@ -55,6 +55,7 @@ public:
     void connectToHost();
     bool isAuthenticated() const;
     bool isConnected() const;
+    bool isClientStateIndicationEnabled() const;
 
     QSslSocket *socket() const { return QXmppStream::socket(); };
     QXmppStanza::Error::Condition xmppStreamError();
@@ -77,6 +78,9 @@ signals:
     /// This signal is emitted when an IQ is received.
     void iqReceived(const QXmppIq&);
 
+    /// This signal is emitted when SSL errors are encountered.
+    void sslErrors(const QList<QSslError> &errors);
+
 protected:
     /// \cond
     // Overridable methods
@@ -85,6 +89,9 @@ protected:
     virtual void handleStream(const QDomElement &element);
     /// \endcond
 
+public slots:
+    virtual void disconnectFromHost();
+
 private slots:
     void _q_dnsLookupFinished();
     void _q_socketDisconnected();
@@ -97,9 +104,6 @@ private slots:
     void pingTimeout();
 
 private:
-    void sendNonSASLAuth(bool plaintext);
-    void sendNonSASLAuthQuery();
-
     friend class QXmppOutgoingClientPrivate;
     QXmppOutgoingClientPrivate * const d;
 };
