@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -34,7 +34,7 @@
 
 #include "QXmppByteStreamIq.h"
 #include "QXmppClient.h"
-#include "QXmppConstants.h"
+#include "QXmppConstants_p.h"
 #include "QXmppIbbIq.h"
 #include "QXmppSocks.h"
 #include "QXmppStreamInitiationIq_p.h"
@@ -220,6 +220,7 @@ public:
 QXmppTransferJobPrivate::QXmppTransferJobPrivate()
     : blockSize(16384),
     client(0),
+    direction(QXmppTransferJob::IncomingDirection),
     done(0),
     error(QXmppTransferJob::NoError),
     hash(QCryptographicHash::Md5),
@@ -714,7 +715,7 @@ void QXmppTransferOutgoingJob::_q_sendData()
         terminate(QXmppTransferJob::FileAccessError);
         return;
     }
-    if (length >= 0)
+    else
     {
         d->socksSocket->write(buffer, length);
         delete [] buffer;
@@ -1155,7 +1156,7 @@ void QXmppTransferManager::_q_iqReceived(const QXmppIq &iq)
                     job->terminate(QXmppTransferJob::ProtocolError);
                 }
             } else {
-                // we could not get host/port from proxy, procede without a proxy
+                // we could not get host/port from proxy, proceed without a proxy
                 if (iq.type() == QXmppIq::Error)
                     socksServerSendOffer(job);
             }
