@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -29,7 +29,7 @@
 #include <QSslKey>
 #include <QSslSocket>
 
-#include "QXmppConstants.h"
+#include "QXmppConstants_p.h"
 #include "QXmppDialback.h"
 #include "QXmppIq.h"
 #include "QXmppIncomingClient.h"
@@ -891,11 +891,7 @@ QXmppSslServer::~QXmppSslServer()
     delete d;
 }
 
-#if QT_VERSION < 0x050000
-void QXmppSslServer::incomingConnection(int socketDescriptor)
-#else
 void QXmppSslServer::incomingConnection(qintptr socketDescriptor)
-#endif
 {
     QSslSocket *socket = new QSslSocket;
     if (!socket->setSocketDescriptor(socketDescriptor)) {
@@ -913,7 +909,7 @@ void QXmppSslServer::incomingConnection(qintptr socketDescriptor)
 }
 
 /// Adds the given certificates to the CA certificate database to be used
-/// for incoming connnections.
+/// for incoming connections.
 ///
 /// \param certificates
 
