@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Author:
  *  Jeremy Lainé
@@ -81,7 +81,9 @@ public:
 
     void addCaCertificates(const QString &caCertificates);
     void setLocalCertificate(const QString &path);
+    void setLocalCertificate(const QSslCertificate &certificate);
     void setPrivateKey(const QString &path);
+    void setPrivateKey(const QSslKey &key);
 
     void close();
     bool listenForClients(const QHostAddress &address = QHostAddress::Any, quint16 port = 5222);
@@ -141,11 +143,7 @@ signals:
     void newConnection(QSslSocket *socket);
 
 private:
-    #if QT_VERSION < 0x050000
-    void incomingConnection(int socketDescriptor);
-    #else
-    void incomingConnection(qintptr socketDescriptor);
-    #endif
+    void incomingConnection(qintptr socketDescriptor) override;
     QXmppSslServerPrivate * const d;
 };
 
