@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Authors:
  *  Jeremy Lainé
@@ -45,6 +45,9 @@ private slots:
     void testXhtml();
     void testSubextensions();
     void testChatMarkers();
+    void testPrivateMessage();
+    void testOutOfBandUrl();
+    void testMessageCorrect();
 };
 
 void tst_QXmppMessage::testBasic_data()
@@ -539,5 +542,78 @@ void tst_QXmppMessage::testChatMarkers()
     serializePacket(serialisationMessage, acknowledgedThreadSerialisation);
 }
 
+
+void tst_QXmppMessage::testPrivateMessage()
+{
+    const QByteArray privateXml(
+                "<message "
+                    "id=\"message-3\" "
+                    "to=\"northumberland@shakespeare.lit/westminster\" "
+                    "from=\"kingrichard@royalty.england.lit/throne\" "
+                    "type=\"chat\">"
+                 "<body>My lord, dispatch; read o'er these articles.</body>"
+                 "<private xmlns='urn:xmpp:carbons:2'/>"
+                "</message>");
+
+    QXmppMessage privateMessage;
+    parsePacket(privateMessage, privateXml);
+    QCOMPARE(privateMessage.isPrivate(), true);
+    privateMessage.setPrivate(true);
+    QCOMPARE(privateMessage.isPrivate(), true);
+
+    privateMessage.setPrivate(false);
+    QCOMPARE(privateMessage.isPrivate(), false);
+
+    QBuffer buffer;
+    buffer.open(QIODevice::ReadWrite);
+    QXmlStreamWriter writer(&buffer);
+    privateMessage.toXml(&writer);
+    QVERIFY(!buffer.data().contains("private"));
+}
+
+void tst_QXmppMessage::testOutOfBandUrl()
+{
+    const QByteArray oobXml(
+        "<message to=\"MaineBoy@jabber.org/home\" "
+                 "from=\"stpeter@jabber.org/work\" "
+                 "type=\"chat\">"
+            "<body>Yeah, but do you have a license to Jabber?</body>"
+            "<x xmlns=\"jabber:x:oob\">"
+                "<url>http://www.jabber.org/images/psa-license.jpg</url>"
+            "</x>"
+        "</message>"
+    );
+    const QString firstUrl = "http://www.jabber.org/images/psa-license.jpg";
+    const QString newUrl = "https://xmpp.org/theme/images/xmpp-logo.svg";
+
+    QXmppMessage oobMessage;
+    parsePacket(oobMessage, oobXml);
+    QCOMPARE(oobMessage.outOfBandUrl(), firstUrl);
+
+    oobMessage.setOutOfBandUrl(newUrl);
+    QCOMPARE(oobMessage.outOfBandUrl(), newUrl);
+
+    // set first url again
+    oobMessage.setOutOfBandUrl(firstUrl);
+    serializePacket(oobMessage, oobXml);
+}
+
+void tst_QXmppMessage::testMessageCorrect()
+{
+    const QByteArray xml(
+        "<message to=\"foo@example.com/QXmpp\" from=\"bar@example.com/QXmpp\" type=\"normal\">"
+          "<body>This is the corrected version.</body>"
+          "<replace xmlns=\"urn:xmpp:message-correct:0\" id=\"badmessage\"/>"
+        "</message>");
+
+    QXmppMessage message;
+    parsePacket(message, xml);
+    QCOMPARE(message.replaceId(), QString("badmessage"));
+    serializePacket(message, xml);
+
+    message.setReplaceId("someotherid");
+    QCOMPARE(message.replaceId(), QString("someotherid"));
+}
+
 QTEST_MAIN(tst_QXmppMessage)
 #include "tst_qxmppmessage.moc"
