@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2014 The QXmpp developers
+ * Copyright (C) 2008-2019 The QXmpp developers
  *
  * Authors:
  *  Manjeet Dahiya
@@ -43,6 +43,7 @@ void tst_QXmppStreamFeatures::testEmpty()
     QCOMPARE(features.sessionMode(), QXmppStreamFeatures::Disabled);
     QCOMPARE(features.nonSaslAuthMode(), QXmppStreamFeatures::Disabled);
     QCOMPARE(features.tlsMode(), QXmppStreamFeatures::Disabled);
+    QCOMPARE(features.clientStateIndicationMode(), QXmppStreamFeatures::Disabled);
     QCOMPARE(features.authMechanisms(), QStringList());
     QCOMPARE(features.compressionMethods(), QStringList());
     serializePacket(features, xml);
@@ -55,6 +56,7 @@ void tst_QXmppStreamFeatures::testFull()
         "<session xmlns=\"urn:ietf:params:xml:ns:xmpp-session\"/>"
         "<auth xmlns=\"http://jabber.org/features/iq-auth\"/>"
         "<starttls xmlns=\"urn:ietf:params:xml:ns:xmpp-tls\"/>"
+        "<csi xmlns=\"urn:xmpp:csi:0\"/>"
         "<compression xmlns=\"http://jabber.org/features/compress\"><method>zlib</method></compression>"
         "<mechanisms xmlns=\"urn:ietf:params:xml:ns:xmpp-sasl\"><mechanism>PLAIN</mechanism></mechanisms>"
         "</stream:features>");
@@ -65,6 +67,7 @@ void tst_QXmppStreamFeatures::testFull()
     QCOMPARE(features.sessionMode(), QXmppStreamFeatures::Enabled);
     QCOMPARE(features.nonSaslAuthMode(), QXmppStreamFeatures::Enabled);
     QCOMPARE(features.tlsMode(), QXmppStreamFeatures::Enabled);
+    QCOMPARE(features.clientStateIndicationMode(), QXmppStreamFeatures::Enabled);
     QCOMPARE(features.authMechanisms(), QStringList() << "PLAIN");
     QCOMPARE(features.compressionMethods(), QStringList() << "zlib");
     serializePacket(features, xml);
